.. _api-utils:

=====
Utils
=====

.. automodule:: projector.utils

Return to :ref:`api`.


Basic
=====

``projector.utils.abspath``
---------------------------

Returns absolute path for given ``*paths``.

``projector.utils.str2obj``
---------------------------

.. autofunction:: projector.utils.str2obj

``projector.utils.using_projector_profile``
-------------------------------------------

.. autofunction:: projector.utils.using_projector_profile

Email
=====

.. autofunction:: projector.utils.email.extract_emails

Helpers
=======

``projector.utils.helpers.get_homedir``
---------------------------------------

.. autofunction:: projector.utils.helpers.get_homedir

